
CREATE OR REPLACE VIEW gn_monitoring.v_export_rencontres_gn2_orthopteres_observations
AS
WITH observers AS (
         SELECT array_agg(r.id_role) AS ids_observers,
            string_agg(concat(r.nom_role, ' ', r.prenom_role), ' ; '::text) AS observers,
            cvo.id_base_visit
           FROM gn_monitoring.cor_visit_observer cvo
             JOIN utilisateurs.t_roles r ON r.id_role = cvo.id_role
          GROUP BY cvo.id_base_visit
        )
 SELECT o.uuid_observation AS unique_id_sinp,
    v.uuid_base_visit AS unique_id_sinp_grp, 
    s.base_site_name AS nom_placette,
    o.id_observation,
    v.id_dataset, 
    t.famille,
    o.cd_nom,
    t.nom_complet AS nom_cite,
    tls.label_default as stade_vie,
    (oc.data ->> 'count_max'::text)::integer AS count_min,
    (oc.data ->> 'count_min'::text)::integer AS count_max,
    alt.altitude_min,
    alt.altitude_max,
    s.geom AS the_geom_4326,
    st_centroid(s.geom) AS the_geom_point,
    s.geom_local AS the_geom_local,
    v.visit_date_min AS date_min,
    COALESCE(v.visit_date_max, v.visit_date_min) AS date_max,
    obs.observers,
    v.id_digitiser,
    v.id_module,
    v.comments AS comment_context,
    o.comments AS comment_description
   FROM gn_monitoring.t_base_visits v
     JOIN gn_monitoring.t_base_sites s ON s.id_base_site = v.id_base_site
     JOIN gn_monitoring.t_observations o ON v.id_base_visit = o.id_base_visit
     JOIN gn_commons.t_modules m ON m.id_module = v.id_module
     JOIN gn_monitoring.t_visit_complements vc ON vc.id_base_visit = v.id_base_visit
     JOIN gn_monitoring.t_observation_complements oc ON oc.id_observation = o.id_observation
     LEFT JOIN ref_nomenclatures.t_nomenclatures tls ON tls.id_nomenclature = (oc.data ->> 'id_nomenclature_life_stage')::int
     JOIN taxonomie.taxref t ON t.cd_nom = o.cd_nom
     LEFT JOIN observers obs ON obs.id_base_visit = v.id_base_visit  
     LEFT JOIN LATERAL ref_geo.fct_get_altitude_intersection(s.geom_local) alt(altitude_min, altitude_max) ON true
  WHERE m.module_code = :module_code;
 